# Changelog

## 1.0.0 (2025-01-09)

Full Changelog: [v0.0.1-alpha.0...v1.0.0](https://github.com/tractorbeamai/tractorbeam-python/compare/v0.0.1-alpha.0...v1.0.0)

### Features

* **api:** update via SDK Studio ([56e910d](https://github.com/tractorbeamai/tractorbeam-python/commit/56e910dce2a13957e6a3dac612cdf4c165172806))
* **api:** update via SDK Studio ([74c4cbf](https://github.com/tractorbeamai/tractorbeam-python/commit/74c4cbf6e72542a39a6ce88e6933dd2370cb149d))
* **api:** update via SDK Studio ([937feb3](https://github.com/tractorbeamai/tractorbeam-python/commit/937feb35527377cf7dade1e2470fa697f98b9c71))
* **api:** update via SDK Studio ([3b3c3e8](https://github.com/tractorbeamai/tractorbeam-python/commit/3b3c3e8e29dc00dbab74601fa61c481df3461e01))
* **api:** update via SDK Studio ([1d9ccd9](https://github.com/tractorbeamai/tractorbeam-python/commit/1d9ccd98dc06d453f1e2cbbce4d0e7377f229472))
* **api:** update via SDK Studio ([44107b7](https://github.com/tractorbeamai/tractorbeam-python/commit/44107b73fbade235b528daa6c0311771c23debc4))


### Chores

* go live ([#1](https://github.com/tractorbeamai/tractorbeam-python/issues/1)) ([03ba10a](https://github.com/tractorbeamai/tractorbeam-python/commit/03ba10a09a18eccb12cdd6beb8a1adc5d38f5504))
* **internal:** bump pydantic dependency ([1401220](https://github.com/tractorbeamai/tractorbeam-python/commit/1401220c89eff07db652618b3fc8e83e66016921))
* **internal:** codegen related update ([8c3e822](https://github.com/tractorbeamai/tractorbeam-python/commit/8c3e82247d96154c4a7e055cf8edb75748393f3a))
* **internal:** codegen related update ([2447901](https://github.com/tractorbeamai/tractorbeam-python/commit/244790147eb1d70924fdad9aeb011d8853049646))
* **internal:** codegen related update ([ecebe86](https://github.com/tractorbeamai/tractorbeam-python/commit/ecebe86dfabec9d0169b1b354ae0802e1dcb0ca8))
* **internal:** codegen related update ([f255707](https://github.com/tractorbeamai/tractorbeam-python/commit/f255707d0dcb507bae105402dbdceae341c06305))
* **internal:** codegen related update ([736097f](https://github.com/tractorbeamai/tractorbeam-python/commit/736097fc9df6a1a4cfbcf065268ba0be7cce04a4))
* **internal:** updated imports ([9da599d](https://github.com/tractorbeamai/tractorbeam-python/commit/9da599dbc7d425cbb28a12b4d709f61f447b7b5d))
* make the `Omit` type public ([0b748c9](https://github.com/tractorbeamai/tractorbeam-python/commit/0b748c9b4890395ff8354fe06b9661d407979840))
* update SDK settings ([#3](https://github.com/tractorbeamai/tractorbeam-python/issues/3)) ([6d9e3e3](https://github.com/tractorbeamai/tractorbeam-python/commit/6d9e3e359102eca204a661e00e01a3766450e1c1))


### Documentation

* **readme:** fix http client proxies example ([d4bb619](https://github.com/tractorbeamai/tractorbeam-python/commit/d4bb619b1cc19e1bf902cbea3627435e1b5b7edf))
